@@ -138,7 +138,7 @@ SEXP R_amatch(SEXP x, SEXP table, SEXP method
     , ntable = length(table)
     , no_match = INTEGER(nomatch)[0]
     , match_na = INTEGER(matchNA)[0]
-    , bytes = INTEGER(x)[0]
+    , bytes = INTEGER(useBytes)[0]
     , ml_x = max_length(x)
     , ml_t = max_length(table)
     , intdist = TYPEOF(x) == VECSXP ? 1 : 0; // list of integers?
@@ -351,18 +351,14 @@ SEXP R_afind(SEXP a, SEXP pattern, SEXP width
   PROTECT(out_list = allocVector(VECSXP, 2));
 
   // output location
-  SEXP out_loc;
-  out_loc = allocMatrix(INTSXP, na, npat);
-  VECTOR_ELT(out_list,0) = out_loc;
+  SEXP out_loc = PROTECT(allocMatrix(INTSXP, na, npat));
+  SET_VECTOR_ELT(out_list,0, out_loc); 
   int *yloc = INTEGER(out_loc);
 
   // output distance
-  SEXP out_dist;
-  out_dist = allocMatrix(REALSXP, na, npat);
-  VECTOR_ELT(out_list,1) = out_dist;
+  SEXP out_dist =  PROTECT(allocMatrix(REALSXP, na, npat));
+  SET_VECTOR_ELT(out_list,1, out_dist);
   double *ydist = REAL(out_dist);
-
-  
   // Setup stringdist structure.
   // find maximum window length
   int max_window = 0;
@@ -398,11 +394,10 @@ SEXP R_afind(SEXP a, SEXP pattern, SEXP width
     t = s + ml_a + 1L;
     
     int len_s, len_t, isna_s, isna_t, max_k, k_min, current_window, offset;
-    int ID, num_threads;
+    int ID=0, num_threads=1;
     
     double d, d_min;
 
-
     #ifdef _OPENMP
     ID = omp_get_thread_num();
     num_threads = omp_get_num_threads();
@@ -440,7 +435,7 @@ SEXP R_afind(SEXP a, SEXP pattern, SEXP width
     } // end loop over strings
     close_stringdist(sd);
   } // end parallel region
-  UNPROTECT(1);
+  UNPROTECT(3);
   return(out_list);
 
 }
